@@ -6,9 +6,8 @@
 #
 #  Authors: Revva Konstantin <k.revva@abm-jsc.ru>
 
-from detector_connector import DetectorConnector
+from detector_connector import DetectorConnector, DetectorAnalyzeResult
 
-from defocus_detector_connector.defocus_analyze_result import DefocusAnalyzeResult
 from defocus_detector_connector.defocus_settings import DefocusSettings
 
 
@@ -19,5 +18,5 @@ class DefocusDetectorConnector(DetectorConnector):
     def __init__(self, config: Config, context: Context):
         super().__init__(config=config,
                          context=context,
-                         detector_analyze_result_type=DefocusAnalyzeResult,
+                         detector_analyze_result_type=DetectorAnalyzeResult,
                          detector_settings_type=DefocusSettings)
